@@ -1,3 +1,5 @@
 from PyQtGuiLib.core.bubbleWidget import BubbleWidget
 from PyQtGuiLib.core.pullOver import PullOver
 from PyQtGuiLib.core.slideShow import SlideShow
+from PyQtGuiLib.core.flowLayout import FlowLayout
+from PyQtGuiLib.core.listWidget import ListWidget
\ No newline at end of file
