@@ -4,7 +4,7 @@
 # @file:qt.py
 # @software:PyCharm
 from PyQtGuiLib.header.versions import PYQT_VERSIONS
-from PyQtGuiLib.header import Qt,QPainter,QStyle,QSizePolicy
+from PyQtGuiLib.header import Qt,QPainter,QStyle,QSizePolicy,QEasingCurve
 
 
 if PYQT_VERSIONS == "PyQt5"  :
@@ -44,6 +44,14 @@ if PYQT_VERSIONS == "PyQt5"  :
     Vertical = Qt.Vertical
     PM_LayoutHorizontalSpacing = QStyle.PM_LayoutHorizontalSpacing
     PM_LayoutVerticalSpacing = QStyle.PM_LayoutVerticalSpacing
+    NoFocus = Qt.NoFocus
+    TabFocus = Qt.TabFocus
+    ClickFocus = Qt.ClickFocus
+    StrongFocus = Qt.StrongFocus
+    OutBounce = QEasingCurve.OutBounce
+    CosineCurve = QEasingCurve.CosineCurve
+    SineCurve = QEasingCurve.SineCurve
+
 
 if PYQT_VERSIONS in ["PyQt6","PySide2","PySide6"]:
     FramelessWindowHint = Qt.WindowType.FramelessWindowHint
@@ -80,4 +88,11 @@ if PYQT_VERSIONS in ["PyQt6","PySide2","PySide6"]:
     Horizontal = Qt.Orientation.Horizontal
     Vertical = Qt.Orientation.Vertical
     PM_LayoutHorizontalSpacing = QStyle.PixelMetric.PM_LayoutHorizontalSpacing
-    PM_LayoutVerticalSpacing = QStyle.PixelMetric.PM_LayoutVerticalSpacing
\ No newline at end of file
+    PM_LayoutVerticalSpacing = QStyle.PixelMetric.PM_LayoutVerticalSpacing
+    NoFocus = Qt.FocusPolicy.NoFocus
+    TabFocus = Qt.FocusPolicy.TabFocus
+    ClickFocus = Qt.FocusPolicy.ClickFocus
+    StrongFocus = Qt.FocusPolicy.StrongFocus
+    OutBounce = QEasingCurve.Type.OutBounce
+    CosineCurve = QEasingCurve.Type.CosineCurve
+    SineCurve = QEasingCurve.Type.SineCurve
\ No newline at end of file
